<?xml version="1.0"?>

<!--
    Simple stylesheet to render HTML from Word-produced XML files
    Elias Karakoulakis
    April 2002
-->

<xsl:stylesheet version="1.0"                
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html"/>
  
<xsl:template match='WordDocument'>
   <html>
        <head>
            <title><xsl:value-of select="documentProperties/builtInProperties/property[@name='Title']"/></title>
            <xsl:apply-templates select='documentStyles'/>
        </head>
        <body>
            <xsl:apply-templates select='documentBody'/>
        </body>
    </html>
</xsl:template>

<xsl:template match='documentStyles'>
    <style type='text/css'>
    <xsl:comment>
        <xsl:for-each select='style[./styleCSSDescription]'>
           .<xsl:value-of select='@name'/> { 
               <xsl:value-of select='styleCSSDescription'/> 
            }
        </xsl:for-each>
    </xsl:comment>
    </style>
</xsl:template>

<xsl:template match='paragraph'>
    <p>
        <xsl:if test='@styleName'>
            <xsl:attribute name='class'><xsl:value-of select='@styleName'/></xsl:attribute>
        </xsl:if>
        <xsl:apply-templates/>
    </p>
</xsl:template>

  <xsl:template match='table'>
    <table border='0' rules="all" frame="bottom">
        <xsl:copy-of select='@cellSpacing'/>
        <xsl:copy-of select='@cellPadding'/>
        <xsl:apply-templates/>
    </table>
  </xsl:template>

  <xsl:template match='row'>
      <tr>
          <xsl:apply-templates/>
        </tr>
  </xsl:template>

  <xsl:template match='cell'>
      <td border='0'>
          <xsl:if test='@bgcolor'><xsl:copy-of select='@bgcolor'/></xsl:if>
          <xsl:if test='@styleName'>
            <xsl:attribute name='class'><xsl:value-of select='@styleName'/></xsl:attribute>
        </xsl:if>
          <xsl:if test='@colspan'>
              <xsl:copy-of select='@colspan'/>
              <!-- <xsl:attribute name='width'><xsl:value-of select='@colspan'/>%</xsl:attribute> -->
          </xsl:if>
          <xsl:attribute name='valign'>
              <xsl:choose>
                  <xsl:when test="@valign='1'">bottom</xsl:when>
                  <xsl:when test="@valign='4'">top</xsl:when>
                </xsl:choose>
            </xsl:attribute>
          <xsl:apply-templates/>
        </td>
  </xsl:template>
  
<xsl:template match="list[@type='1']|list[@type='2']">
    <ul>
        <xsl:apply-templates/>
    </ul>
</xsl:template>

<xsl:template match="list">
    <ol>
        <xsl:apply-templates/>
    </ol>
</xsl:template>

<xsl:template match='listItem'>
    <li>
        <xsl:if test='@styleName'><xsl:attribute name='class'><xsl:value-of select='@styleName'/></xsl:attribute></xsl:if>
        <xsl:apply-templates/>
    </li>
</xsl:template>

<xsl:template match="inlineShape[@type='linkedPicture']">
    <img>
        <xsl:attribute name='src'><xsl:value-of select="@filename"/></xsl:attribute>
    </img>
</xsl:template>

<xsl:template match="styledText[@styleName='Hyperlink']">
  <a href='{@target}'>
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="styledText">
    <span class='{@styleName}'>
        <xsl:apply-templates/>
    </span>
</xsl:template>

<xsl:template match="hyperlink">
    <a>
        <xsl:copy-of select="@href"/>
        <xsl:apply-templates/>
    </a>
</xsl:template>

</xsl:stylesheet>